@@ -52,12 +52,4 @@
 #undef	CYGWIN_IMPORTS
 #endif
 
-#undef  CCXX_EXPORT
-#define CCXX_EXPORT(t) __EXPORT t
-#undef  CCXX_MEMBER
-#define CCXX_MEMBER(t) t
-#undef  CCXX_MEMBER_EXPORT
-#define CCXX_MEMBER_EXPORT(t) __EXPORT CCXX_MEMBER(t CCXX_EMPTY)
-#undef  CCXX_CLASS_EXPORT
-#define CCXX_CLASS_EXPORT __EXPORT
 #endif
