@@ -161,6 +161,11 @@ protected:
 	 */
 	void purge(void);
 
+	/**
+	 * Clean for memory cleanup before exiting.
+	 */
+	void clean(void);
+
 	/**
 	 * Delete the memory pool and all allocated memory.
 	 */
