@@ -166,6 +166,7 @@ public:
 	Date(char *str, size_t size = 0);
 	Date(int year, unsigned month, unsigned day);
 	Date();
+	virtual ~Date();
 
 	int getYear(void) const;
 	unsigned getMonth(void) const;
@@ -226,6 +227,7 @@ public:
 	Time(char *str, size_t size = 0);
 	Time(int hour, int minute, int second);	
 	Time();
+	virtual ~Time();
 
 	long getValue(void) const;
 	int getHour(void) const;
@@ -281,6 +283,7 @@ class __EXPORT Datetime : public Date, public Time
 	Datetime(int year, unsigned month, unsigned day,
 		 int hour, int minute, int second);
 	Datetime();
+	virtual ~Datetime();
 	
 	char *getDatetime(char *buffer) const;
 	time_t getDatetime(void) const;
@@ -317,6 +320,7 @@ protected:
 
 public:
 	DateNumber(char *buffer);
+	virtual ~DateNumber();
 };
 
 #ifdef	CCXX_NAMESPACES
