@@ -70,6 +70,10 @@ typedef int SOCKET;
 #define	MSG_DONTWAIT	0
 #endif
 
+#ifndef	MSG_NOSIGNAL
+#define	MSG_NOSIGNAL	0
+#endif
+
 #ifdef	CCXX_NAMESPACES
 namespace ost {
 #endif
@@ -993,7 +997,7 @@ protected:
 	 * @param len of bytes to send.
 	 */
 	inline ssize_t send(const void *buf, size_t len)
-		{return _IORET64 ::send(so, (const char *)buf, _IOLEN64 len, 0);}
+		{return _IORET64 ::send(so, (const char *)buf, _IOLEN64 len, MSG_NOSIGNAL);}
 
 	/**
 	 * Stop transmitter.
@@ -1026,7 +1030,7 @@ public:
 	 * @param len of bytes to send.
 	 */
 	inline ssize_t transmit(const char *buffer, size_t len)
-		{return _IORET64 ::send(so, buffer, _IOLEN64 len, MSG_DONTWAIT);}
+		{return _IORET64 ::send(so, buffer, _IOLEN64 len, MSG_DONTWAIT|MSG_NOSIGNAL);}
 
 	/**
 	 * See if output queue is empty for sending more packets.
