@@ -86,6 +86,11 @@ MemPager::MemPager(size_t pg)
 }
 
 MemPager::~MemPager()
+{
+	clean();
+}
+
+void MemPager::clean(void)
 {
 	struct _page *root = page;
 
