@@ -351,7 +351,7 @@ ssize_t Socket::readLine(char *str, size_t request, timeout_t timeout)
 				break;
 			}
 		}
-		nstat = ::recv(so, str, c, 0);
+		nstat = ::recv(so, str, _IOLEN64 c, 0);
 		// TODO: correct ???
 		if(nstat < 0)
 			break;
@@ -3023,7 +3023,7 @@ int TCPStream::underflow()
             return EOF;
 		}
 		else
-			rlen = ::recv(so, (char *)&ch, 1, 0);
+			rlen = readData(&ch, 1);
 		if(rlen < 1)
 		{
 			if(rlen < 0)
@@ -3052,7 +3052,7 @@ int TCPStream::underflow()
 		return EOF;
 	}
 	else
-		rlen = ::recv(so, (char *)eback(), rlen, 0);
+		rlen = readData(eback(), rlen);
 	if(rlen < 1)
 	{
 //		clear(ios::failbit | rdstate());
@@ -3105,7 +3105,7 @@ size_t TCPStream::printf(const char *format, ...)
 	if(Socket::state == STREAM)
 		return ::write((int)so, buf, _IOLEN64 len);
 	else
-		return ::send(so, buf, _IOLEN64 len, MSG_NOSIGNAL);
+		return writeData(buf, len);
 }
 #endif
 
@@ -3123,7 +3123,7 @@ int TCPStream::overflow(int c)
 		if(Socket::state == STREAM)
 			rlen = ::write((int)so, (const char *)&ch, 1);
 		else
-			rlen = ::send(so, (const char *)&ch, 1, MSG_NOSIGNAL);
+			rlen = writeData(&ch, 1);
 		if(rlen < 1)
 		{
 			if(rlen < 0)
@@ -3146,7 +3146,7 @@ int TCPStream::overflow(int c)
 		if(Socket::state == STREAM)
 			rlen = ::write((int)so, (const char *)pbase(), req);
 		else
-			rlen = ::send(so, (const char *)pbase(), req, MSG_NOSIGNAL);
+			rlen = writeData(pbase(), req);
 		if(rlen < 1)
 		{
 			if(rlen < 0)
